
//@HEADER
// ***************************************************
//
// HPCG: High Performance Conjugate Gradient Benchmark
//
// Contact:
// Michael A. Heroux ( maherou@sandia.gov)
// Jack Dongarra     (dongarra@eecs.utk.edu)
// Piotr Luszczek    (luszczek@eecs.utk.edu)
//
// ***************************************************
//@HEADER

#ifndef COMPUTEDOTPRODUCT_HPP
#define COMPUTEDOTPRODUCT_HPP
#include "Geometry.hpp"
int ComputeDotProduct(const local_int_t n, const double * const x, const double * const y,
    double * const result, double & time_allreduce, bool & isOptimized);

#endif // COMPUTEDOTPRODUCT_HPP
